#!/usr/bin/python


def GetLastArticleTime(filefp):
	Checker = 0
	filefp.seek(0)
	for line in filefp:
		if '<pubDate>' in line:
			if Checker == 1:
				break
			Checker += 1
	line = line.replace('<pubDate>','')
	line = line.replace('</pubDate>','')
	line = line.strip()
	return line
